#! /usr/bin/env node
'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _regexgen = require('regexgen');

var _packageData = require('../packageData');

var _packageData2 = _interopRequireDefault(_packageData);

var _writeFile = require('./helpers/writeFile');

var _writeFile2 = _interopRequireDefault(_writeFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var codePointGroups = {
  4: new _regexgen.Trie(),
  3: new _regexgen.Trie(),
  2: new _regexgen.Trie(),
  1: new _regexgen.Trie()
};
/**
 * @copyright   2017, Miles Johnson
 * @license     https://opensource.org/licenses/MIT
 */


console.log('Generating regex pattern');

_promise2.default.resolve((0, _packageData2.default)()).then(function (data) {
  data.forEach(function (emoji) {
    var group = emoji.codepoint.length;

    if (group <= 0 || group > 4) {
      return;
    }

    codePointGroups[group].add(emoji.unicode);
  });

  return data;
}).then(function () {
  return [4, 3, 2, 1].map(function (group) {
    return '(?:' + codePointGroups[group].toRegExp().source + ')';
  }).join('|');
}).then(function (regex) {
  return (0, _writeFile2.default)(_path2.default.join(__dirname, '../../regex/index.js'), regex, function (pattern) {
    return 'module.exports = /' + pattern + '/;\n';
  }, false);
}).then(function () {
  return (0, _writeFile2.default)(_path2.default.join(__dirname, '../../regex/shortname.js'), ':[-+\\w]+:', function (pattern) {
    return 'module.exports = /' + pattern + '/;\n';
  }, false);
}).then(function () {
  console.log(_chalk2.default.green('Regex generated successfully'));
}).catch(function (error) {
  console.log(_chalk2.default.red('Failed to generate regex pattern'));
  console.log(_chalk2.default.gray(error.message));
});