'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CACHE = exports.EMOJI_ONE = exports.EMOJI = undefined;

var _fromCodePoint = require('babel-runtime/core-js/string/from-code-point');

var _fromCodePoint2 = _interopRequireDefault(_fromCodePoint);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

exports.default = packageData;

var _diacritics = require('diacritics');

var _unicodeEmojiData = require('unicode-emoji-data');

var _emoji = require('emojione/emoji.json');

var _emoji2 = _interopRequireDefault(_emoji);

var _createTags = require('./createTags');

var _createTags2 = _interopRequireDefault(_createTags);

var _createShortnames = require('./createShortnames');

var _createShortnames2 = _interopRequireDefault(_createShortnames);

var _extractGender = require('./extractGender');

var _extractGender2 = _interopRequireDefault(_extractGender);

var _extractSkinTone = require('./extractSkinTone');

var _extractSkinTone2 = _interopRequireDefault(_extractSkinTone);

var _fromHexToCodepoint = require('./fromHexToCodepoint');

var _fromHexToCodepoint2 = _interopRequireDefault(_fromHexToCodepoint);

var _constants = require('./constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var WS_PATTERN = /\s+/g; /**
                          * @copyright   2017, Miles Johnson
                          * @license     https://opensource.org/licenses/MIT
                          * 
                          */

var EMOJI = exports.EMOJI = (0, _unicodeEmojiData.expandEmojiData)(_unicodeEmojiData.emojiData);

var EMOJI_ONE = exports.EMOJI_ONE = {};

(0, _keys2.default)(_emoji2.default).forEach(function (hexcode) {
  EMOJI_ONE[hexcode.toUpperCase()] = _emoji2.default[hexcode];
});

var CACHE = exports.CACHE = [];

function packageData() {
  if (CACHE.length) {
    return CACHE;
  }

  EMOJI.forEach(function (emoji) {
    var hexcodeZWJ = emoji.presentation && emoji.presentation.default ? emoji.presentation.default : emoji.codepoint;

    if (!hexcodeZWJ) {
      return;
    }

    var name = emoji.name,
        defaultPresentation = emoji.defaultPresentation;

    var unicode = _fromCodePoint2.default.apply(String, (0, _toConsumableArray3.default)((0, _fromHexToCodepoint2.default)(hexcodeZWJ.replace(WS_PATTERN, '-'))));

    var hexcode = hexcodeZWJ.replace(_constants.SEQUENCE_REMOVAL_PATTERN, '').trim().replace(WS_PATTERN, '-');

    var extraEmoji = {
      category: 'other',
      codepoint: (0, _fromHexToCodepoint2.default)(hexcode),
      display: defaultPresentation === 'emoji' ? 1 : 0,
      gender: (0, _extractGender2.default)(name),
      hexcode: hexcode,
      name: name,
      order: null,
      skin: (0, _extractSkinTone2.default)(name),
      shortnames: (0, _createShortnames2.default)(name),
      tags: (0, _createTags2.default)(name),
      unicode: unicode
    };

    if (EMOJI_ONE[hexcode]) {
      var emojiOne = EMOJI_ONE[hexcode];

      extraEmoji.category = emojiOne.category;
      extraEmoji.order = emojiOne.order;

      var tags = emojiOne.keywords.filter(function (kw) {
        return kw !== '';
      }).map(function (kw) {
        return (0, _diacritics.remove)(kw).replace(/ /g, '-').replace(/\.|“|”|’/g, '');
      });

      if (tags.length) {
        extraEmoji.tags = tags;
      }

      extraEmoji.shortnames = [emojiOne.shortname].concat(emojiOne.shortname_alternates).map(function (sn) {
        return sn.replace(/:/g, '');
      });

      delete EMOJI_ONE[hexcode];
    }

    CACHE.push(extraEmoji);
  });

  CACHE.sort(function (a, b) {
    return a.order - b.order;
  });

  return CACHE;
}